@@ -1,6 +1,6 @@
-DELETE IGNORE FROM mysql.plugin WHERE name = 'mroonga';
+DELETE IGNORE FROM mysql.plugin WHERE dl = 'ha_mroonga.so';
 
-INSTALL PLUGIN mroonga SONAME 'ha_mroonga.so';
+INSTALL PLUGIN Mroonga SONAME 'ha_mroonga.so';
 
 DROP FUNCTION IF EXISTS last_insert_grn_id;
 CREATE FUNCTION last_insert_grn_id RETURNS INTEGER
@@ -17,3 +17,7 @@ CREATE FUNCTION mroonga_command RETURNS STRING
 DROP FUNCTION IF EXISTS mroonga_escape;
 CREATE FUNCTION mroonga_escape RETURNS STRING
   SONAME 'ha_mroonga.so';
+
+DROP FUNCTION IF EXISTS mroonga_snippet_html;
+CREATE FUNCTION mroonga_snippet_html RETURNS STRING
+  SONAME 'ha_mroonga.so';
